Learn R Programming

gglabeller (version 0.3.1)

gglabeller_example: gglabeller_example

Description

Example output from gglabeller function

Usage

gglabeller_example

Arguments

Format

list with three elements: the plot, the indices for rows of data that are labelled, and the code to regenerate the plot